@@ -9,13 +9,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
- 'BINLIBDEST': '/usr/local/lib/python3.6',
- 'BLDLIBRARY': '-L. -lpython3.6m',
+ 'BINLIBDEST': '/usr/local/lib/python3.7',
+ 'BLDLIBRARY': '-L. -lpython3.7m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/pobj/Python-3.6.9/Python-3.6.9',
+              '-L/usr/obj/ports/Python-3.7.4/Python-3.7.4',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'i386-unknown-openbsd6.6',
+ 'BUILD_GNU_TYPE': 'arm-unknown-openbsd6.6',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -30,12 +30,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wstrict-prototypes',
+                            '-Wstrict-prototypes '
+                            '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-loadable-sqlite-extensions' "
-                "'--enable-shared' '--srcdir=/pobj/Python-3.6.9/Python-3.6.9' "
+                "'--enable-shared' "
+                "'--srcdir=/usr/obj/ports/Python-3.7.4/Python-3.7.4' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
                 "'--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
@@ -44,25 +46,25 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' "
                 "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
- 'CONFINCLUDEPY': '/usr/local/include/python3.6m',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/pobj/Python-3.6.9/Python-3.6.9/coverage.info',
- 'COVERAGE_REPORT': '/pobj/Python-3.6.9/Python-3.6.9/lcov-report',
+ 'CONFINCLUDEPY': '/usr/local/include/python3.7m',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.7.4/Python-3.7.4/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.7.4/Python-3.7.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.6 '
-             '/usr/local/lib/python3.6/lib-dynload',
- 'DESTLIB': '/usr/local/lib/python3.6',
+ 'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.7 '
+             '/usr/local/lib/python3.7/lib-dynload',
+ 'DESTLIB': '/usr/local/lib/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/local/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/usr/local/lib/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
@@ -78,7 +80,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
@@ -94,7 +95,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 0,
+ 'HAVE_ALIGNED_REQUIRED': 1,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -124,6 +125,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 0,
+ 'HAVE_CRYPT_R': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
  'HAVE_CURSES_FILTER': 1,
@@ -145,6 +147,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 0,
  'HAVE_DECL_RTLD_NOLOAD': 0,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -200,7 +203,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -271,6 +274,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LINUX_VM_SOCKETS_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -279,7 +283,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LUTIMES': 0,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -305,12 +308,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 0,
  'HAVE_POSIX_FALLOCATE': 0,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 1,
+ 'HAVE_PREADV2': 0,
  'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -318,13 +324,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 1,
+ 'HAVE_PWRITEV2': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -339,7 +346,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SCHED_SETAFFINITY': 0,
  'HAVE_SCHED_SETPARAM': 0,
  'HAVE_SCHED_SETSCHEDULER': 0,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -365,6 +371,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 0,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -466,6 +473,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 1,
+ 'HAVE_UUID_ENC_BE': 1,
+ 'HAVE_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 0,
@@ -477,41 +487,42 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.6',
+ 'HOST_GNU_TYPE': 'arm-unknown-openbsd6.6',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
-                   '/usr/local/include/python3.6m '
-                   '/usr/local/include/python3.6m',
+                   '/usr/local/include/python3.7m '
+                   '/usr/local/include/python3.7m',
  'INCLUDEDIR': '/usr/local/include',
- 'INCLUDEPY': '/usr/local/include/python3.6m',
- 'INSTALL': '/pobj/Python-3.6.9/bin/install -c',
- 'INSTALL_DATA': '/pobj/Python-3.6.9/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/pobj/Python-3.6.9/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/pobj/Python-3.6.9/bin/install -c -m 755',
- 'INSTALL_SHARED': '/pobj/Python-3.6.9/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.6m.so.0.0',
+ 'INCLUDEPY': '/usr/local/include/python3.7m',
+ 'INSTALL': '/usr/obj/ports/Python-3.7.4/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.7.4/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.7.4/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.7.4/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.7.4/bin/install -c -m 555',
+ 'INSTSONAME': 'libpython3.7m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/pobj/Python-3.6.9/Python-3.6.9',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.7.4/Python-3.7.4',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6m.so',
+ 'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/pobj/Python-3.6.9/Python-3.6.9',
- 'LDVERSION': '3.6m',
+             '-L/usr/obj/ports/Python-3.7.4/Python-3.7.4',
+ 'LDVERSION': '3.7m',
  'LIBC': '',
- 'LIBDEST': '/usr/local/lib/python3.6',
+ 'LIBDEST': '/usr/local/lib/python3.7',
  'LIBDIR': '/usr/local/lib',
  'LIBFFI_INCLUDEDIR': '/usr/local/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/local/lib/pkgconfig',
- 'LIBPL': '/usr/local/lib/python3.6/config-3.6m',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPL': '/usr/local/lib/python3.7/config-3.7m',
+ 'LIBRARY': 'libpython3.7m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -lpthread  -lutil',
@@ -524,11 +535,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LLVM_PROF_MERGER': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
- 'LOG1P_DROPS_ZERO_SIGN': 1,
+ 'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'openbsd6',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/local/lib/python3.6',
+ 'MACHDESTLIB': '/usr/local/lib/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -536,29 +546,34 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/local/man',
  'MKDIR_P': 'mkdir -p',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
+                   '_operator  _collections  _abc  itertools  atexit  _signal  '
+                   '_stat  time  _thread  _locale  _io  zipimport  '
+                   'faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _signal _stat time '
-             '_locale _io zipimport faulthandler _tracemalloc _symtable '
-             'xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
-            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
-            'Modules/_codecsmodule.o  Modules/_weakref.o  '
-            'Modules/_functoolsmodule.o  Modules/_operator.o  '
-            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/_abc.o  Modules/itertoolsmodule.o  '
             'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
-            'Modules/timemodule.o  Modules/_localemodule.o  '
-            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
-            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
-            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/timemodule.o  Modules/_threadmodule.o  '
+            'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
+            'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
+            'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
+            'Modules/faulthandler.o  Modules/_tracemalloc.o '
+            'Modules/hashtable.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MULTIARCH_CPPFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '',
+ 'OPENSSL_LDFLAGS': '',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -574,10 +589,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '',
  'PGO_PROF_USE_FLAG': '',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': 'libpython3.so',
@@ -587,26 +602,48 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
+                             '-O2 -pipe -O2 -pipe -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
+                             '-Werror=implicit-function-declaration -I. '
+                             '-I./Include -I/usr/local/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
               '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes',
+                     '-Wstrict-prototypes '
+                     '-Werror=implicit-function-declaration',
+ 'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
                    '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes -I. '
-                   '-I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -L/pobj/Python-3.6.9/Python-3.6.9',
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -I. -I./Include '
+                   '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
+                    '-L/usr/obj/ports/Python-3.7.4/Python-3.7.4',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/pobj/Python-3.6.9/Python-3.6.9',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.7.4/Python-3.7.4',
  'PY_LDFLAGS_NODIST': '',
+ 'PY_SSL_DEFAULT_CIPHERS': 1,
+ 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
+                        '-Werror=implicit-function-declaration -I. -I./Include '
+                        '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -614,10 +651,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/pobj/Python-3.6.9/Python-3.6.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.4/Python-3.7.4',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lintl -lpthread  -lutil',
  'SHLIB_SUFFIX': '.so',
@@ -628,10 +665,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 4,
  'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 4,
@@ -640,8 +678,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
+ 'SOABI': 'cpython-37m',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -655,12 +693,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/pobj/Python-3.6.9/Python-3.6.9 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.4/Python-3.7.4 '
+               './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/pobj/Python-3.6.9/Python-3.6.9 ./python '
-               './Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.4/Python-3.7.4 '
+               './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
@@ -668,9 +706,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
- 'WANT_SIGFPE_HANDLER': 1,
+ 'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -678,12 +714,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pobj/Python-3.6.9/Python-3.6.9',
- 'abs_srcdir': '/pobj/Python-3.6.9/Python-3.6.9',
+ 'abs_builddir': '/usr/obj/ports/Python-3.7.4/Python-3.7.4',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.7.4/Python-3.7.4',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
